==> suir-component-mapper-3.3.2.tgz: package/esm/wizard/wizard.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import Wizard from '@data-driven-forms/common/wizard/wizard';
import WizardNav from './wizard-nav';
import WizardStepButtons from './step-buttons';

var WizardInternal = function WizardInternal(_ref) {
  var buttonLabels = _ref.buttonLabels,
      stepsInfo = _ref.stepsInfo;

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      onKeyDown = _useContext.onKeyDown,
      handleNext = _useContext.handleNext,
      activeStepIndex = _useContext.activeStepIndex,
      prevSteps = _useContext.prevSteps;

  var buttonLabelsFinal = _objectSpread({
    next: 'Continue',
    submit: 'Submit',
    cancel: 'Cancel',
    back: 'Back'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement("div", {
    onKeyDown: onKeyDown
  }, stepsInfo && /*#__PURE__*/React.createElement(WizardNav, {
    stepsInfo: stepsInfo,
    activeStepIndex: activeStepIndex
  }), /*#__PURE__*/React.createElement("div", null, currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  }), /*#__PURE__*/React.createElement(WizardStepButtons, _extends({}, currentStep, {
    formOptions: formOptions,
    buttonLabels: buttonLabelsFinal,
    handleNext: handleNext,
    handlePrev: handlePrev,
    disableBack: prevSteps.length === 0
  }))));
};

WizardInternal.propTypes = {
  buttonLabels: PropTypes.object,
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node,
    label: PropTypes.node,
    StepLabelProps: PropTypes.object,
    StepProps: PropTypes.object
  }))
};

var SuirWizard = function SuirWizard(props) {
  return /*#__PURE__*/React.createElement(Wizard, _extends({
    Wizard: WizardInternal
  }, props));
};

export default SuirWizard;

==> suir-component-mapper-3.12.0.tgz: package/esm/wizard/wizard.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import Wizard from '@data-driven-forms/common/wizard/wizard';
import WizardNav from './wizard-nav';
import WizardStepButtons from './step-buttons';

var WizardInternal = function WizardInternal(_ref) {
  var buttonLabels = _ref.buttonLabels,
      stepsInfo = _ref.stepsInfo,
      conditionalSubmitFlag = _ref.conditionalSubmitFlag;

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      onKeyDown = _useContext.onKeyDown,
      handleNext = _useContext.handleNext,
      activeStepIndex = _useContext.activeStepIndex,
      prevSteps = _useContext.prevSteps;

  var buttonLabelsFinal = _objectSpread({
    next: 'Continue',
    submit: 'Submit',
    cancel: 'Cancel',
    back: 'Back'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement("div", {
    onKeyDown: onKeyDown
  }, stepsInfo && /*#__PURE__*/React.createElement(WizardNav, {
    stepsInfo: stepsInfo,
    activeStepIndex: activeStepIndex
  }), /*#__PURE__*/React.createElement("div", null, currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  }), /*#__PURE__*/React.createElement(WizardStepButtons, _extends({}, currentStep, {
    conditionalSubmitFlag: conditionalSubmitFlag,
    formOptions: formOptions,
    buttonLabels: buttonLabelsFinal,
    handleNext: handleNext,
    handlePrev: handlePrev,
    disableBack: prevSteps.length === 0
  }))));
};

WizardInternal.propTypes = {
  buttonLabels: PropTypes.object,
  conditionalSubmitFlag: PropTypes.string.isRequired,
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node,
    label: PropTypes.node,
    StepLabelProps: PropTypes.object,
    StepProps: PropTypes.object
  }))
};

var SuirWizard = function SuirWizard(props) {
  return /*#__PURE__*/React.createElement(Wizard, _extends({
    Wizard: WizardInternal
  }, props));
};

export default SuirWizard;
